<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0">
    <xsl:output method="html" encoding="UTF-8" indent="yes" />
    
    <xsl:template match="bank">
        <html>
            <body>
                <h1>Monte dei Paschi di Rende</h1>
                <xsl:apply-templates select="." mode="view-by-accounts" />
                <xsl:apply-templates select="." mode="view-by-customers" />
            </body>
        </html>
    </xsl:template>
    
    <xsl:template match="bank" mode="view-by-accounts">
        <h2>View by accounts</h2>

        <h3>Bank accounts</h3>
        <table border="1">
            <tr>
                <th>ID account</th>
                <th>Customer</th>
                <th>Balance</th>
            </tr>
            <xsl:apply-templates select="accounts/bank-accounts/bank-account" mode="view-by-accounts" />
        </table>
        
        <h3>Deposit accounts</h3>
        <table border="1">
            <tr>
                <th>ID account</th>
                <th>Customer</th>
                <th>Balance</th>
                <th>Interest rate</th>
                <th>Interest</th>
                <th>Notes</th>
            </tr>
            <xsl:apply-templates select="accounts/deposit-accounts/deposit-account" mode="view-by-accounts" />
        </table>
    </xsl:template>
    
    <xsl:template match="bank-account" mode="view-by-accounts">
        <xsl:variable name="id" select="@id" />
        <tr>
            <td><xsl:value-of select="@id" /></td>
            <td><xsl:value-of select="//customer[.//bank-account/@ref = $id]/name" /></td>
            <td><xsl:apply-templates select="balance" /></td>
        </tr>
    </xsl:template>

    <xsl:template match="deposit-account" mode="view-by-accounts">
        <xsl:variable name="id" select="@id" />
        <tr>
            <td><xsl:value-of select="@id" /></td>
            <td><xsl:value-of select="//customer[.//deposit-account/@ref = $id]/name" /></td>
            <td><xsl:apply-templates select="balance" /></td>
            <td><xsl:value-of select="@interesse * 100" />%</td>
            <td><xsl:value-of select="balance * @interesse" /></td>
            <td>
                <xsl:if test="balance >= 10000">
                    Propose gold option!
                </xsl:if>
            </td>
        </tr>
    </xsl:template>
    
    <xsl:template match="balance">
        <xsl:value-of select="." />
    </xsl:template>

    <xsl:template match="balance[. &lt; 0]">
        <strong><xsl:value-of select="." /></strong>
    </xsl:template>
    
    <xsl:template match="bank" mode="view-by-customers">
        <h2>View by customers</h2>
        
        <xsl:apply-templates select="customers/customer" mode="view-by-customers" />
    </xsl:template>
    
    <xsl:template match="customer" mode="view-by-customers">
        <xsl:variable name="refs" select=".//@ref" />
        <h3><xsl:value-of select="name" /></h3>
        
        <table border="1">
            <tr>
                <th>ID account</th>
                <th>Balance</th>
            </tr>
            <xsl:apply-templates select="accounts/*" mode="view-by-customers" />
            <tr>
                <th>Total</th>
                <th><xsl:value-of select="sum(//balance[../@id = $refs])" /></th>
            </tr>
        </table>
    </xsl:template>
    
    <xsl:template match="bank-account | deposit-account" mode="view-by-customers">
        <xsl:variable name="id" select="@ref" />
        <tr>
            <td><xsl:value-of select="@ref" /></td>
            <td><xsl:apply-templates select="//*[@id = $id]/balance" /></td>
        </tr>
    </xsl:template>
    
</xsl:stylesheet>







